#!/bin/bash
# Script for cleaning all the autogenerated and temporary data.
#
# Thomas Guillod - Dartmouth College
# Mozilla Public License Version 2.0

set -o nounset
set -o pipefail

# change to root directory
cd "$(dirname "$0")" && cd ..

# clean Python caches
find . -path '*/__pycache__/*' -type f -delete
find . -name "__pycache__" -type d -delete

# clean Jupyter checkpoints
find . -path '*/.ipynb_checkpoints/*' -type f -delete
find . -name ".ipynb_checkpoints" -type d -delete

# clean Python objects
find . \( -name "*.pyc" -o -name "*.pyo" \) -type f -delete

# clean temp files
find . \( -name "*.log" -o -name "*.bak" \) -type f -delete

# clean gzip files
find . \( -name "*.gz" -o -name "*.gzip" \) -type f -delete

# clean pickle files
find . \( -name "*.pck" -o -name "*.pkl" -o -name "*.pickle" \) -type f -delete

# clean generated files
rm -rf pypeec/data/version.txt
rm -rf pypeec/data/examples.tar.xz
rm -rf pypeec/data/documentation.tar.xz

# clean package data
rm -rf dist
rm -rf build
rm -rf pypeec.egg-info

# clean generated folders
rm -rf html
rm -rf website
rm -rf coverage

# clean Sphinx data
rm -rf docs/_static
rm -rf docs/_templates

exit 0
